%global _hardened_build 1

%global with_modperl 1

%global __python %{__python3}
%global with_modpython 1

Name:           znc
Version:        1.9.1
Release:    1%{?dist}
Summary:        An advanced IRC bouncer

License:        Apache-2.0
URL:            https://znc.in
Source0:        %{url}/releases/archive/%{name}-%{version}.tar.gz
Patch0:         0001-Use-system-wide-crypto-policy.patch

BuildRequires:  c-ares-devel
BuildRequires:  cmake
BuildRequires:  cyrus-sasl-devel
BuildRequires:  gcc-c++
BuildRequires:  gettext-devel
BuildRequires:  gnupg2
BuildRequires:  libicu-devel
BuildRequires:  make

BuildRequires:  openssl-devel >= 0.9.8
BuildRequires:  perl(ExtUtils::Embed)


Requires(pre):  shadow-utils
BuildRequires:  systemd
%{?systemd_requires}

%description
ZNC is an IRC bouncer with many advanced features like detaching,
multiple users, per channel playback buffer, SSL, IPv6, transparent
DCC bouncing, Perl and C++ module support to name a few.

%package devel
Summary:        Development files needed to compile ZNC modules
Requires:       %{name} = %{version}-%{release} pkgconfig
Requires:       openssl-devel c-ares-devel glibc-devel libicu-devel
BuildRequires:  pkgconfig
Requires:       gcc-c++
Requires:       system-rpm-config

%description devel
All includes and program files you need to compile your own znc
modules.

%package modtcl
Summary:       TCL module for ZNC

BuildRequires: tcl-devel

Requires:      %{name} = %{version}-%{release}
Requires:      tcl

%description modtcl
%{summary}.

%if 0%{?with_modperl}
%package modperl
Summary:       Perl module for ZNC

BuildRequires: perl-devel
BuildRequires: perl-generators
BuildRequires: swig

Requires:      %{name} = %{version}-%{release}
Requires:      perl-interpreter

Provides:      perl(ZNC::Module) = %{version}-%{release}

%description modperl
%{summary}.
%endif


%if 0%{?with_modpython}
%package modpython
Summary:       Python3 module for ZNC

BuildRequires: python%{python3_pkgversion}-devel
BuildRequires: swig

Requires:      %{name} = %{version}-%{release}
Requires:      python%{python3_pkgversion}

%description modpython
%{summary}.
%endif


%prep
%autosetup -p1

sed -ie 's!/usr/local/!/usr/!' man/znc.1

%build

%ifarch aarch64
%global _smp_build_ncpus 1
%endif

%cmake \
    -DWANT_PERL=1 \
    -DWANT_PYTHON=1 \
    -DWANT_SYSTEMD=1 \
    -DSYSTEMD_DIR=%{_unitdir} \
    -DWANT_IPV6=1 \
    -DWANT_CYRUS=1 \
    -DWANT_TCL=1

%cmake_build

%install
%cmake_install
install -d "%{buildroot}%{_sharedstatedir}/znc"
%py_byte_compile %{__python3} %{buildroot}%{_libdir}/znc/


%pre
getent group znc >/dev/null || groupadd -r znc
getent passwd znc >/dev/null || \
    useradd -r -g znc -d /var/lib/znc -s /sbin/nologin \
    -c "Account for ZNC to run as" znc


%post
%systemd_post znc.service


%postun
%systemd_postun_with_restart znc.service


%preun
%systemd_preun znc.service


%files
%doc ChangeLog.md NOTICE README.md
%license LICENSE
%{_bindir}/znc
%{_mandir}/man1/znc.1*
%{_libdir}/znc
%exclude %{_libdir}/znc/modperl/
%exclude %{_libdir}/znc/modperl.so
%exclude %{_libdir}/znc/perleval.pm
%if 0%{?with_modpython}
%exclude %{_libdir}/znc/__pycache__/
%exclude %{_libdir}/znc/modpython/
%exclude %{_libdir}/znc/modpython.so
%exclude %{_libdir}/znc/pyeval.py
%endif # 0%{?with_modpython}
%exclude %{_libdir}/znc/modtcl.so
%{_datadir}/znc/
%{_datadir}/locale/*/LC_MESSAGES/*.mo
%exclude %{_datadir}/znc/modtcl/
%{_unitdir}/znc.service
%attr(-,znc,znc) %{_sharedstatedir}/znc/

%files devel
%{_bindir}/znc-buildmod
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/znc/
%{_mandir}/man1/znc-buildmod.1*

%files modtcl
%{_libdir}/znc/modtcl.so
%{_datadir}/znc/modtcl/

%if 0%{?with_modperl}
%files modperl
%{_libdir}/znc/modperl/
%{_libdir}/znc/modperl.so
%{_libdir}/znc/perleval.pm
%endif # 0%{?with_modperl}

%if 0%{?with_modpython}
%files modpython
%{_libdir}/znc/modpython/
%{_libdir}/znc/modpython.so
%{_libdir}/znc/pyeval.py
%{_libdir}/znc/__pycache__/
%endif # 0%{?with_modpython}


%changelog
* Tue Feb 25 2025 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.9.1-1
- bump version to 1.9.1

* Fri Jan 10 2025 bbrucezhang <bbrucezhang@tencent.com> - 1.8.2-4
- Rebuild for icu-74.2

* Tue Oct 08 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.8.2-3
- using system-rpm-config

* Tue Aug 06 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.8.2-2
- fix requires

* Fri Apr 12 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.8.2-1
- initial build
